pub struct Email {Show 14 fields
pub from: String,
pub to: String,
pub cc: Option<String>,
pub bcc: Option<String>,
pub subject: Option<String>,
pub body: Body,
pub tag: Option<String>,
pub reply_to: Option<String>,
pub headers: Option<Vec<Header>>,
pub track_opens: Option<bool>,
pub track_links: Option<TrackLink>,
pub attachments: Option<Vec<Attachment>>,
pub metadata: Option<HashMap<String, String>>,
pub message_stream: Option<String>,
}Fields
from: StringFrom: The sender email address. Must have a registered and confirmed Sender Signature.
to: StringTo: Recipient email address. Multiple addresses are comma separated. Max 50.
cc: Option<String>Cc recipient email address. Multiple addresses are comma separated. Max 50.
bcc: Option<String>Bcc recipient email address. Multiple addresses are comma separated. Max 50.
subject: Option<String>Email subject
body: BodyThe body of the message
tag: Option<String>Email tag that allows you to categorize outgoing emails and get detailed statistics.
reply_to: Option<String>Reply To override email address. Defaults to the Reply To set in the sender signature.
headers: Option<Vec<Header>>List of custom headers to include.
track_opens: Option<bool>Activate open tracking for this email.
track_links: Option<TrackLink>Activate link tracking for links in the HTML or Text bodies of this email.
attachments: Option<Vec<Attachment>>List of attachments
metadata: Option<HashMap<String, String>>Custom metadata key/value pairs.
message_stream: Option<String>Set message stream ID that’s used for sending. If not provided, message will default to the “outbound” transactional stream.